//
//  CharacteristicsTableViewController.swift
//  HomeKitExample
//
//  Created by Scott Lee on 2016. 10. 20..
//  Copyright © 2016년 Studio G.B.U. All rights reserved.
//

import UIKit
import HomeKit

class CharacteristicsTableViewController: UITableViewController, HMAccessoryDelegate {
    var accessory: HMAccessory?
    var data = [HMCharacteristic]()

    override func viewDidLoad() {
        super.viewDidLoad()
        navigationItem.title = accessory!.name
        
        for service in accessory!.services {
            if service.serviceType == HMServiceTypeLightbulb {
                for characteristic in service.characteristics {
                    data.append(characteristic as HMCharacteristic)
                }
            }
        }
        
        accessory?.delegate = self
    }
    
    override func tableView(_ tableView: UITableView, numberOfRowsInSection section: Int) -> Int {
        return data.count
    }
    
    override func numberOfSections(in tableView: UITableView) -> Int {
        return 1
    }
    
    override func tableView(_ tableView: UITableView, cellForRowAt indexPath: IndexPath) -> UITableViewCell {
        let cell = tableView.dequeueReusableCell(withIdentifier: "CharacteristicCell", for: indexPath)
        let characteristic = data[indexPath.row] as HMCharacteristic
        let metadata = characteristic.metadata as HMCharacteristicMetadata!

        if metadata?.format == HMCharacteristicMetadataFormatBool {
            cell.textLabel?.text = characteristic.metadata?.manufacturerDescription!
            
            if characteristic.value as! Bool == true {
                cell.detailTextLabel?.text = "ON"
            } else {
                cell.detailTextLabel?.text = "OFF"
            }
            
            characteristic.enableNotification(true, completionHandler: { (error) -> Void in
                if error != nil {
                    print("수정 상태로 변경 실패 \(error!.localizedDescription)")
                }
            })
        } else {
            cell.textLabel?.text = characteristic.metadata?.manufacturerDescription
            cell.detailTextLabel?.text = "\(characteristic.value!)"
        }
        
        return cell
    }
    
    override func tableView(_ tableView: UITableView, didSelectRowAt indexPath: IndexPath) {
        tableView.deselectRow(at: indexPath, animated: true)
        
        let characteristic = data[indexPath.row] as HMCharacteristic
        let metadata = characteristic.metadata as HMCharacteristicMetadata!
        
        if metadata?.format == HMCharacteristicMetadataFormatBool {
            let toggleState = (characteristic.value as! Bool) ? false : true
            characteristic.writeValue(NSNumber(value: toggleState), completionHandler: { (error) -> Void in
                if error != nil {
                    print("값 변경 실패 \(error!.localizedDescription)")
                }
                
                self.tableView.reloadData()
            })
        }
    }
    
    func accessory(_ accessory: HMAccessory, service: HMService, didUpdateValueFor characteristic: HMCharacteristic) {
        print("값 변경 발생 \(characteristic.value)")
        tableView.reloadData()
    }
}

