//
//  BodyInfoTableViewController.swift
//  HealthKitExample
//
//  Created by Scott Lee on 2016. 10. 21..
//  Copyright © 2016년 Studio G.B.U. All rights reserved.
//

import UIKit
import HealthKit

class BodyInfoTableViewController: UITableViewController {
    let hkStore: HKHealthStore = HKHealthStore()
    
    var heightSamples = [HKQuantitySample]()
    var weightSamples = [HKQuantitySample]()
    var bfpSamples = [HKQuantitySample]()
    var lbmSamples = [HKQuantitySample]()
    var bmiSamples = [HKQuantitySample]()
    
    let dateFormatter = DateFormatter()
    
    override func viewDidLoad() {
        dateFormatter.dateStyle = .medium
    }
    
    override func viewDidAppear(_ animated: Bool) {
        getBodyInfo()
        tableView.reloadData()
    }
    
    func getBodyInfo() {
        let endDate = Date()
        let startDate = Calendar.current.date(byAdding: .month, value: -3, to: endDate)
        
        let heightSampleType = HKObjectType.quantityType(forIdentifier: HKQuantityTypeIdentifier.height)
        let weightSampleType = HKObjectType.quantityType(forIdentifier: HKQuantityTypeIdentifier.bodyMass)
        let bfpSampleType = HKObjectType.quantityType(forIdentifier: HKQuantityTypeIdentifier.bodyFatPercentage)
        let lbmSampleType = HKObjectType.quantityType(forIdentifier: HKQuantityTypeIdentifier.leanBodyMass)
        let bmiSampleType = HKObjectType.quantityType(forIdentifier: HKQuantityTypeIdentifier.bodyMassIndex)
        
        let predicate = HKQuery.predicateForSamples(withStart: startDate, end: endDate, options: HKQueryOptions())
        let sortDescriptor = NSSortDescriptor(key: HKSampleSortIdentifierStartDate, ascending: false)
        
        var query = HKSampleQuery(sampleType: heightSampleType!, predicate: predicate, limit: 0, sortDescriptors: [sortDescriptor], resultsHandler: {
            (query, results, error) in
            if (results == nil) {
                print("신장 조회 오류 : \(error)")
            }
            DispatchQueue.main.async {
                self.heightSamples = results as! [HKQuantitySample]
            }
        })
        self.hkStore.execute(query)
        
        query = HKSampleQuery(sampleType: weightSampleType!, predicate: predicate, limit: 0, sortDescriptors: [sortDescriptor], resultsHandler: {
            (query, results, error) in
            if (results == nil) {
                print("체중 조회 오류 : \(error)")
            }
            DispatchQueue.main.async {
                self.weightSamples = results as! [HKQuantitySample]
            }
        })
        self.hkStore.execute(query)
        
        query = HKSampleQuery(sampleType: bfpSampleType!, predicate: predicate, limit: 0, sortDescriptors: [sortDescriptor], resultsHandler: {
            (query, results, error) in
            if (results == nil) {
                print("체지방 조회 오류 : \(error)")
            }
            DispatchQueue.main.async {
                self.bfpSamples = results as! [HKQuantitySample]
            }
        })
        self.hkStore.execute(query)
        
        query = HKSampleQuery(sampleType: lbmSampleType!, predicate: predicate, limit: 0, sortDescriptors: [sortDescriptor], resultsHandler: {
            (query, results, error) in
            if (results == nil) {
                print("제지방 체중 조회 오류 : \(error)")
            }
            DispatchQueue.main.async {
                self.lbmSamples = results as! [HKQuantitySample]
            }
        })
        self.hkStore.execute(query)
        
        query = HKSampleQuery(sampleType: bmiSampleType!, predicate: predicate, limit: 0, sortDescriptors: nil, resultsHandler: {
            (query, results, error) in
            if (results == nil) {
                print("체질량 지수 조회 오류 : \(error)")
            }
            DispatchQueue.main.async {
                self.bmiSamples = results as! [HKQuantitySample]
                self.tableView.reloadData()
            }
        })
        self.hkStore.execute(query)
    }
    
    override func tableView(_ tableView: UITableView, numberOfRowsInSection section: Int) -> Int {
        return heightSamples.count
    }
    
    override func tableView(_ tableView: UITableView, cellForRowAt indexPath: IndexPath) -> UITableViewCell {
        let cell = tableView.dequeueReusableCell(withIdentifier: "BICell", for: indexPath)
        let weight = weightSamples[indexPath.row].quantity.doubleValue(for: HKUnit(from: "kg"))
        let height = heightSamples[indexPath.row].quantity.doubleValue(for: HKUnit(from: "cm"))
        let bfp = bfpSamples[indexPath.row].quantity.doubleValue(for: HKUnit.percent())
        let lbm = lbmSamples[indexPath.row].quantity.doubleValue(for: HKUnit(from: "kg"))
        let bmi = bmiSamples[indexPath.row].quantity.doubleValue(for: HKUnit.count())
        let date = weightSamples[indexPath.row].startDate
        
        cell.textLabel!.text = "\(dateFormatter.string(from: date)) - \(height)cm, \(weight)kg"
        
        cell.detailTextLabel!.text = "BFP : \(bfp * 100)%, LBM : \(lbm)kg, BMI : \(bmi)BMI"
        
        return cell
    }
}
